pub fn bootstrap_phase1_world(
tick_rate: u64,
extra_registry: impl FnOnce(&mut ComponentRegistry),
) -> BevyWorldAdapterExpand description
Bootstraps a Phase 1 world with the default engine components and optional extra registrations.
pub fn bootstrap_phase1_world(
tick_rate: u64,
extra_registry: impl FnOnce(&mut ComponentRegistry),
) -> BevyWorldAdapterBootstraps a Phase 1 world with the default engine components and optional extra registrations.