pub struct TickScheduler { /* private fields */ }Expand description
Manages the fixed-timestep execution of the game loop.
Implementations
Sourceimpl TickScheduler
impl TickScheduler
Sourcepub fn new(tick_rate: u64, auth_service: AuthServiceImpl) -> Self
pub fn new(tick_rate: u64, auth_service: AuthServiceImpl) -> Self
Creates a new scheduler with the specified tick rate.
Sourcepub async fn run(
&mut self,
transport: Box<dyn GameTransport>,
world: Box<dyn WorldState>,
encoder: Box<dyn Encoder>,
shutdown: Receiver<()>,
)
pub async fn run( &mut self, transport: Box<dyn GameTransport>, world: Box<dyn WorldState>, encoder: Box<dyn Encoder>, shutdown: Receiver<()>, )
Runs the infinite game loop until the shutdown token is cancelled.
Sourcepub async fn tick_step(
transport: &mut dyn GameTransport,
world: &mut dyn WorldState,
encoder: &dyn Encoder,
auth_service: &AuthServiceImpl,
authenticated_clients: &mut HashMap<ClientId, (String, NetworkId)>,
reassembler: &mut Reassembler,
next_message_id: &mut u32,
encode_buffer: &mut [u8],
tick: u64,
)
pub async fn tick_step( transport: &mut dyn GameTransport, world: &mut dyn WorldState, encoder: &dyn Encoder, auth_service: &AuthServiceImpl, authenticated_clients: &mut HashMap<ClientId, (String, NetworkId)>, reassembler: &mut Reassembler, next_message_id: &mut u32, encode_buffer: &mut [u8], tick: u64, )
Executes a single 5-stage tick pipeline.